<?php 
header("Content-type: image/png");

// function to get a variable value from its name :
function getVar($varname, $defaultval) {
	if (isset($_GET[$varname])) return ($_GET[$varname]);
	return ($defaultval);
}

// get sizes and board direction :
$squareSize = getVar("sqz",35);
$numRows = 8 * $squareSize;
$numCols = $numRows;
$direction = getVar("dir","wd");

// get squares colors :
function getColors($hexcol) {
	$r = hexdec(substr($hexcol,0,2));
	$g = hexdec(substr($hexcol,2,2));
	$b = hexdec(substr($hexcol,4,2));
	return (array(0 => $r, 1 => $g, 2 => $b));
}

// create empty board with dark and light squares :
$board = imageCreateTrueColor($numRows, $numCols);
imageAlphaBlending($board, 1);
$hex_light = getVar("lcol","fffff0");
$hex_dark = getVar("dcol","29a197");
$rgb_light = getColors($hex_light);
$rgb_dark = getColors($hex_dark);
$light_square_color = imageColorAllocate($board, $rgb_light[0], $rgb_light[1], $rgb_light[2]);
$dark_square_color = imageColorAllocate($board, $rgb_dark[0], $rgb_dark[1], $rgb_dark[2]);
for ($rank = 0; $rank < 8; $rank++) {
	for ($file = 0; $file < 8; $file++) {
		$sq_color = ($rank + $file) % 2 ? $dark_square_color : $light_square_color;
		$x1 = $file * $squareSize;
		$y1 = $rank * $squareSize;
		$x2 = $x1 + $squareSize - 1;
		$y2 = $y1 + $squareSize - 1;
		imageFilledRectangle($board, $x1, $y1, $x2, $y2, $sq_color);
	}
}

// now preload every possible type of piece (avoid multi-loading) :
$fenStr = getVar("fen","");
if (strlen($fenStr) == 0) exit("FEN string missing !");
$black_pawn = NULL;
$black_rook = NULL;
$black_knight = NULL;
$black_bishop = NULL;
$black_queen = NULL;
$white_pawn = NULL;
$white_rook = NULL;
$white_knight = NULL;
$white_bishop = NULL;
$white_queen = NULL;
$basePiecePath = "./pieces/" . getVar("psty","merida") . "/";
if (preg_match("/p/", $fenStr))
	$black_pawn = imageCreateFromPNG($basePiecePath . "black_pawn" . ".png");
if (preg_match("/r/", $fenStr))
	$black_rook = imageCreateFromPNG($basePiecePath . "black_rook" . ".png");
if (preg_match("/n/", $fenStr))
	$black_knight = imageCreateFromPNG($basePiecePath . "black_knight" . ".png");
if (preg_match("/b/", $fenStr))
	$black_bishop = imageCreateFromPNG($basePiecePath . "black_bishop" . ".png");
if (preg_match("/q/", $fenStr))
	$black_queen = imageCreateFromPNG($basePiecePath . "black_queen" . ".png");
$black_king = imageCreateFromPNG($basePiecePath . "black_king" . ".png");
if (preg_match("/P/", $fenStr))
	$white_pawn = imageCreateFromPNG($basePiecePath . "white_pawn" . ".png");
if (preg_match("/R/", $fenStr))
	$white_rook = imageCreateFromPNG($basePiecePath . "white_rook" . ".png");
if (preg_match("/N/", $fenStr))
	$white_knight = imageCreateFromPNG($basePiecePath . "white_knight" . ".png");
if (preg_match("/B/", $fenStr))
	$white_bishop = imageCreateFromPNG($basePiecePath . "white_bishop" . ".png");
if (preg_match("/Q/", $fenStr))
	$white_queen = imageCreateFromPNG($basePiecePath . "white_queen" . ".png");
$white_king = imageCreateFromPNG($basePiecePath . "white_king" . ".png");

// function to add a piece image on the chessboard image :
function addPiece($piece,$rank,$file) {
	global $board;
	global $squareSize;
	global $direction;
	if ($direction == "wd") {
		$x = $file * $squareSize;
		$y = $rank * $squareSize;
	}
	else {
		$x = (7 - $file) * $squareSize;
		$y = (7 - $rank) * $squareSize;
	}
	$pieceSize = imageSx($piece);
	imageCopyResampled($board,$piece,$x,$y,0,0,$squareSize,$squareSize,$pieceSize,$pieceSize);
}

// we finally parse fen string AND add pieces in the same time
$curRank = 0;
$curFile = 0;
for ($k = 0; $k < strlen($fenStr); $k++) {
	$char = $fenStr[$k];	
	if ($char == '/') {
		$curRank++;
		$curFile = 0;
		continue;
	}
    // faut-il dessiner une piece ?
    $onePiece = TRUE;
	switch ($char) {
	case 'p':
		$piece = $black_pawn;
		break;
	case 'r': 
		$piece = $black_rook;
		break;
	case 'n':
		$piece = $black_knight;
		break;
	case 'b':
		$piece = $black_bishop;
		break;
	case 'q':
		$piece = $black_queen;
		break;
	case 'k':
		$piece = $black_king;
		break;
	case 'P':
		$piece = $white_pawn;
		break;
	case 'R':
		$piece = $white_rook;
		break;
	case 'N':
		$piece = $white_knight;
		break;
	case 'B':
		$piece = $white_bishop;
		break;
	case 'Q':
		$piece = $white_queen;
		break;
	case 'K':
		$piece = $white_king;
		break;
	default:
		$onePiece = FALSE;
		if ($char >= '1' && $char <= '8') $curFile += $char;
	}
	if ($onePiece) addPiece($piece,$curRank,$curFile++);
}

// output final board :
imagePNG($board);

// free memory :
imageDestroy($board);
if ($black_pawn!==NULL) imageDestroy($black_pawn);
if ($black_rook!==NULL) imageDestroy($black_rook);
if ($black_knight!==NULL) imageDestroy($black_knight);
if ($black_bishop!==NULL) imageDestroy($black_bishop);
if ($black_queen!==NULL) imageDestroy($black_queen);
imageDestroy($black_king);
if ($white_pawn!==NULL) imageDestroy($white_pawn);
if ($white_rook!==NULL) imageDestroy($white_rook);
if ($white_knight!==NULL) imageDestroy($white_knight);
if ($white_bishop!==NULL) imageDestroy($white_bishop);
if ($white_queen!==NULL) imageDestroy($white_queen);
imageDestroy($white_king);

?>

